@@ -17,6 +17,8 @@ class Cfg(object):
         404: lambda rq: wsgi.Response(wsgi.HTML_404, code=404, content_type='text/html'),
         500: lambda rq: wsgi.Response(wsgi.HTML_500, code=500, content_type='text/html'),
     }
+    TEMPLATE_CACHE_SIZE = 250
+    TEMPLATE_AUTO_RELOAD = False
 
     def set_defaults(self, **kwargs):
         '''
