@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import jinja2
 import wsgi
+from config import cfg
 
 def load_template(fn):
     ERR_MSG = 'template not found: %s' % fn
@@ -14,23 +15,18 @@ def load_template(fn):
             assert 0, ERR_MSG
     return f.read().decode('utf-8')
 
-
-TEMPLATE_CACHE = {}
-JINJA_ENV = jinja2.Environment(
-    loader = jinja2.FunctionLoader(load_template),
-    autoescape = True,
-)
-
-def get_template(fn):
-    try:
-        template = TEMPLATE_CACHE[fn]
-    except KeyError:
-        template = JINJA_ENV.get_template(fn)
-        TEMPLATE_CACHE[fn] = template
-    return template
-
 def render_to_string(fn, context):
-    return get_template(fn).render(context)
+    global _ENV
+    try:
+        return _ENV.get_template(fn).render(context)
+    except NameError:
+        _ENV = jinja2.Environment(
+            loader = jinja2.FunctionLoader(load_template),
+            autoescape = True,
+            cache_size = cfg.TEMPLATE_CACHE_SIZE,
+            auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
+        )        
+        return _ENV.get_template(fn).render(context)
     
 def render_to_response(rq, fn, context, **response_kwargs):
     rq.context.update(context)
